/* jshint browser:true */
/* jshint devel:true */
/* global $, moment, _, d3  */
'use strict';

(function () {

var url = $.url();
var server = url.param('server');
var token = url.param('token');
var tab = url.param('tabs') || 'actions';

// main data store
var data = null;

//device pixel density
//var dR = window.devicePixelRatio;
var dR = 1;

//chceck the screen width
var width = $('#content').width() - 8 * 2 * dR;

var durationStart = moment().startOf('month'); // today as the start of the current month

/* dummy data for vis */
function Data() {
    //include all the apps each of which is one of the top 5 counts at one of the 6-hour slots.
    //returned with descending order of [sum of all the 4 counts]
    this.topActions = [
        { name: 'Chrome', count: [110, 10, 20, 50] }, //count: [12am-6am, 6am-12pm, 12pm-6pm, 6pm-12am]
        { name: 'WhatsApp', count: [80, 35, 60, 0] },
        { name: 'Text Zoe Daley', count: [50, 40, 10, 15] },
        { name: 'FaceBook', count: [70, 40, 30, 10] },
        { name: 'Twitter', count: [40, 30, 100, 10] },
        { name: 'Netflix', count: [10, 0, 15, 20] },
        { name: 'Amazon', count: [0, 5, 5, 0] }
    ];
    // every contact without having the name and number can have the attributes below
    //          uId : 'D71A5113A7FD582AE5C09DA7CE2E84F2420CBBD1',
    //          contactUId : '914E9F8C58D31A518189F5E6923F3C41456259FC',
    // which will be negotiated at runtime for name and number
    this.topContacts = [ //up to 5
        { name: 'Tanyoung Kim',
          number: '408-505-7691',
          call: {
            incoming: [10, 40, 10, 20, 5, 2, 4, 1], // by 3 hours: 12am-3am, 3am-6am, ...
            outgoing: [30, 40, 5, 3, 1, 10, 8, 2]
          },
          sms: {
            incoming: [20, 10, 10, 5, 2, 4, 1, 20],
            outgoing: [1, 10, 8, 2, 30, 30, 5, 3]
          }
        },
        { name: 'Simon Turvey',
          number: '111-505-7691',
          call: {
            incoming: [20, 20, 10, 20, 5, 2, 4, 1],
            outgoing: [10, 40, 5, 3, 1, 10, 8, 2]
          },
          sms: {
            incoming: [10, 40, 10, 20, 5, 2, 4, 1],
            outgoing: [30, 10, 5, 3, 1, 10, 8, 2]
          }
        },
        { name: '',
          number: '222-505-7691',
          call: {
            incoming: [20, 20, 10, 20, 5, 2, 4, 1],
            outgoing: [10, 40, 5, 3, 1, 10, 8, 2]
          },
          sms: {
            incoming: [30, 10, 5, 3, 1, 10, 8, 2],
            outgoing: [10, 40, 10, 20, 5, 2, 4, 1]
          }
        },
        { name: '',
          number: '111-505-7691',
          call: {
            incoming: [20, 20, 10, 20, 5, 2, 4, 1],
            outgoing: [10, 40, 5, 3, 1, 10, 8, 2]
          },
          sms: {
            incoming: [10, 40, 10, 20, 5, 2, 4, 1],
            outgoing: [30, 10, 5, 3, 1, 10, 8, 2]
          }
        },
        { name: '',
          number: '222-222-7691',
          call: {
            incoming: [10, 20, 10, 20, 5, 2, 4, 1],
            outgoing: [10, 30, 5, 3, 1, 10, 8, 2]
          },
          sms: {
            incoming: [10, 20, 10, 20, 5, 2, 4, 1],
            outgoing: [30, 10, 5, 3, 1, 10, 30, 2]
          }
        }
    ];
    this.topLocations = [
        { city: 'Sunnyvale',
          lat: 37.376035,
          lon: -122.034219,
          areas: [ // let's worry about this field
            {lat: 37.376035, lon: -122.034219, u: 1200},
            {lat: 37.386035, lon: -121.034219, u: 500}
          ]
        },
        { city: 'Mountain View',
          lat: 37.389271,
          lon: -122.085785 ,
          areas: [
            {lat: 37.389271, lon: -122.085785 ,u: 1500}
          ]
        },
        { city: 'Santa Cruz',
          lat: 36.972838,
          lon: -122.029089,
          areas: [
            {lat: 36.972838, lon: -122.029089 ,u: 820}
          ]
        }
    ];
}

/* visualizations */

//actions
function showActions() {

    //colors
    var colors = ['#33B5E5', '#AA66CC', '#99CC00', '#FFBB33', '#FF4444', '#E5E5E5'];

    //sizing
    // we use a layout of 1 : 1
    var containerWidth = width - (32 + 16) * dR;
    var barLabelPadding = 3;
    var barHeight = (24 + 8) * 5 * dR;
    var parallelWidth = width - 110 * dR;
    var parallelHeight = 180 * dR;
    $('#actions-bar').attr('width', containerWidth).attr('height', barHeight - 8 * dR); //svg bars
    $('#actions-parallel').attr('width', width).attr('height', parallelHeight); //svg parallel
    $('#actions-parallel-g').attr('transform', 'translate(' + 110 * dR + ', ' + 4 * dR + ')');

    // amend overall launch count
    var highestCount = 0;
    data.topActions.forEach(function (entry) {
        entry.fullCount = entry.count.reduce(function (a, b) {
            return a + b;
        });

        highestCount = highestCount < entry.fullCount ? entry.fullCount : highestCount;
    });

    // sort by highest launch count
    data.topActions.sort(function (a, b) {
        return b.fullCount - a.fullCount;
    });

    // reduce topActions to top five
    data.topActions.splice(5);
    //clear data
    d3.select('#actions-bar-g').selectAll("*").remove();
    //update name & bar
    var barFraction = (containerWidth / 2) / highestCount;
    data.topActions.forEach(function (item, i) {
        d3.select('#actions-bar-g').append('text')
            .attr('x', 0)
            .attr('y', (17 + i * 33) * dR)
            .text(item.name)
            .attr('class', 'actions-names-list js-ac-names-list-' + i)
            .on('click', function () {
                toggleHighlight(i);
            });
         d3.select('#actions-bar-g').append('rect')
            .attr('width', item.fullCount * barFraction)
            .attr('height', 18 * dR)
            .attr('x', (containerWidth / 2) )
            .attr('y', (4 + i * 33) * dR)
            .style('fill', colors[i])
            .attr('class', 'actions-bar-rect js-ac-bar-' + i)
            .on('click', function () {
                toggleHighlight(i);
            });
        d3.select('#actions-bar-g').append('text')
            .text(item.fullCount)
            .attr('x', (containerWidth / 2) + barLabelPadding)
            .attr('y', (17 + i * 33) * dR)
            .attr('class', 'actions-bar-text js-ac-text-' + i)
            .on('click', function () {
                toggleHighlight(i);
            });
    });
    //draw parallel chart
    var sumByTime = [];
    var countsByTimePerApp = _.map(data.topActions, function (a) {
        var points = _.map(_.range(4), function (i) {
            var sortedByTime = _.sortBy(_.map(data.topActions, function (a) {
                return {
                    app: a.name,
                    count: a.count[i]
                };
            }), function (c) {
                return c.count;
            }).reverse();

            var accCount = 0;
            for (var j = 0; j < data.topActions.length; j++) {
                var count = sortedByTime[j].count;
                accCount = accCount + count;
                if (j === data.topActions.length - 1) {
                    sumByTime.push(accCount);
                }
                if (sortedByTime[j].app === a.name) {
                    return {
                        x: accCount,
                        y: i,
                        count: count
                    };
                }
            }
        });

        var blankPoints = _.map(points, function (p) { // for closed path
            return {
                x: p.x - p.count,
                y: p.y,
                count: 1
            };
        }).reverse();

        return _.union(points, blankPoints);
    });

    //draw parallel
    var xVal = d3.scale.linear().range([0, parallelWidth]).domain([0, _.max(sumByTime)]);
    var yVal = d3.scale.ordinal().rangeBands([0, parallelHeight-32], 1, 0.1).domain([0, 1, 2, 3]); //200: svg height
    var yAxis = d3.svg.axis().scale(yVal).orient('left').tickFormat(function(d) { return ['12AM - 6AM', '6AM - 12PM', '12PM - 6PM', '6PM - 12AM'][d]; });
    d3.select('#actions-parallel').append('g').attr('transform', 'translate(9, 5)').attr('class', 'parallel-axis js-y');
    d3.select('.js-y').call(yAxis);

    var blockH = 10 * dR;
    function parallelPath(app) {
        var pS = 'M ' + xVal(app[0].x)+ ' ' + (yVal(app[0].y) - blockH); //starting path, my
        var pM = ''; //middle path
        for (var i = 0; i < 7; i++) {
            var mx = xVal(app[i].x);
            var x = xVal(app[i+1].x);
            var my = yVal(app[i].y) + ((i<4)? +1: -1) * blockH;
            var y = yVal(app[i+1].y) + ((i<3)? -1: +1) * blockH;
            var tention = Math.abs(app[i].x - app[i+1].x) * (1 - 0.8) / _.max(sumByTime) + 0.8; //more curvy when y difference is bigger
            pM = pM + ' V ' + my + ' C ' + //create Cubic Bezier //mx
                 (x + mx) / 2 + ' ' + //x1
                 (my * tention + y * (1 - tention)) + ' ' + //y1
                 (x + mx) / 2 + ' ' + //x2
                 (my * (1- tention) + y * tention) + ' ' + //y2
                 x + ' ' + y; //x, y
        }
        var pE = ' V ' + (yVal(app[7].y) - blockH) + ' Z '; //ending path
        var path = pS + pM + pE;
        return path;
    }

    d3.selection.prototype.moveToFront = function() {
        return this.each(function(){
            this.parentNode.appendChild(this);
        });
    };

    var currentHighlightId = null;

    function toggleHighlight(id) {
        d3.select('.js-vis-app-0').attr('opacity', '0.5');
        d3.select('.js-vis-app-1').attr('opacity', '0.5');
        d3.select('.js-vis-app-2').attr('opacity', '0.5');
        d3.select('.js-vis-app-3').attr('opacity', '0.5');
        d3.select('.js-vis-app-4').attr('opacity', '0.5');

        if (currentHighlightId === id) {
            $('.js-ac-parallel').html('Tap a block');
            currentHighlightId = null;
            return;
        }

        currentHighlightId = id;

        d3.select('.js-vis-app-' + id).attr('opacity', '1.0');
        d3.select('.js-vis-app-' + id).moveToFront();
        $('.js-ac-parallel').html(data.topActions[id].name); //show the name of selected action
    }

    // remove old graph elements
    var graphNode = $('#actions-parallel-g')[0];
    while (graphNode.firstChild) {
        graphNode.removeChild(graphNode.firstChild);
    }

    _.each(countsByTimePerApp, function(app, i) { //path
        var appColor = colors[i];
        for (var j = 0; j < 4; j++) { //draw overlaid block
            d3.select('#actions-parallel-g').append('rect') //block
                .attr('x', xVal(app[j].x - app[j].count))
                .attr('y', yVal(app[j].y) - blockH)
                .attr('width', xVal(app[j].count))
                .attr('height', blockH * 2)
                .attr('fill', appColor)
                .attr('class', 'js-vis-app js-vis-app-block-' + j);
        }
        d3.select('#actions-parallel-g').append('path') //path
            .attr('d', parallelPath(app))
            .attr('fill', appColor)
            .attr('stroke', '#000000')
            .attr('opacity', '0.5')
            .attr('class', 'js-vis-app js-vis-app-' + i)
            .on('click', function() {
                toggleHighlight(i);
            });
    });
}

//conctacts
function showContacts() {
    var selectedId = 0;
    var selectedKind = 'call';

    //put pictures
    $('.js-con-pics').html('');
    for (var i = 0; i < data.topContacts.length; i++) {
        $('.js-con-pics').append('<li class="contacts-pics-list js-co-pics-list-' + i + '" data-value="' + i + '">' +
            '<img src="images/temp-contact.png" width="' + 46 * dR + '" height="' + 46 * dR + '" class="contacts-pics-list-pic"></li>');
        $('.js-co-pics-list-' + i).mouseover(function() {
            $(this).find('img').css('border', 'solid 0.2em rgba(54, 181, 228, 0.3)');
        }).mouseout(function() {
            $(this).find('img').css('border', 'solid 0.2em #000');
            $('.js-co-pics-list-' + selectedId).find('img').css('border', 'solid 0.2em #36B5E4');
        }).click(function() {
            $('.contacts-pics-list-pic').css('border', 'solid 0.2em #000');
            selectedId = $(this).data().value;
            updateContent(selectedId);
        });
    }

    //vis dimensions
    var visWidth = width - 32 * dR; //paddings
    var visHeight = 170 * dR;
    var colors= {
        call: { incoming: '#F2C358', outgoing: '#f2932c' },
        sms: { incoming: '#81cfe0', outgoing: '#009e9a' }
    };

    //outgoing-incoming vis
    $('#contacts-vis-dir').html('');
    var visDir = d3.select('#contacts-vis-dir').append('svg')
        .attr('width', visWidth)
        .attr('height', visHeight)
        .append('g');

    //lines
    _.each(_.range(3), function (i) {
        visDir.append('line')
            .attr('x1', visWidth/3 + i * visWidth/6)
            .attr('y1', 16 * dR)
            .attr('x2', visWidth/3 + i * visWidth/6)
            .attr('y2', visHeight - 16 * dR)
            .attr('class', 'vis-dashed');
    });

    //icons
    _.each(['call', 'sms'], function (k, i) {
        visDir.append('image')
            .attr('xlink:href', 'images/' + k + '.png')
            .attr('x', visWidth/2 - 14 * dR + (i === 0? -visWidth/12: visWidth/12))
            .attr('y', visHeight/2 - 14 * dR)
            .attr('height', 27 * dR)
            .attr('width', 27 * dR);
    });

    //pics
    visDir.append('image')
        .attr('xlink:href', 'images/temp-contact.png') //change to the contact pic
        .attr('x', visWidth/6 - 24 * dR)
        .attr('y', visHeight/2 - 24 * dR)
        .attr('height', 48 * dR)
        .attr('width', 48 * dR);
    visDir.append('image')
        .attr('xlink:href', 'images/temp-contact.png') //change to the contact pic
        .attr('x', visWidth - visWidth/6 - 24 * dR)
        .attr('y', visHeight/2 - 24 * dR)
        .attr('height', 48 * dR)
        .attr('width', 48 * dR)
        .attr('class', 'js-contact-selected-pic');

    _.each(['outgoing', 'incoming'], function (d, i) {

        // label
        visDir.append('text')
            .attr('x', visWidth/2)
            .attr('y', i === 0? 16 * dR: visHeight - 7 * dR)
            .text(d)
            .attr('class', 'vis-text-grey');

        //arrow
        visDir.append('path')
            .attr('d', i === 0? 'M 0 0 L ' + 16 * dR + ' ' + 10 * dR +' L 0 ' + 20 * dR +
                ' Z': 'M 0 0 L ' + (-16 * dR) + ' ' + 10 * dR + ' L 0 ' + 20 * dR + ' Z')
            .attr('fill', '#999')
            .attr('transform', 'translate(' + (visWidth/2 + 5) + ', ' + (i === 0? 50 * dR: visHeight - 70 * dR) + ')')
            .attr('class', 'js-arrow-head-' + d);
        visDir.append('rect')
            .attr('x', i === 0? -10: 0)
            .attr('y', 0)
            .attr('width', 10 * dR)
            .attr('height', 8 * dR)
            .attr('fill', '#999')
            .attr('transform', 'translate(' + (visWidth/2 + 5) + ', ' + (i === 0? 56 * dR: visHeight - 64 * dR) + ')')
            .attr('class', 'js-arrow-' + d);
        _.each(['call', 'sms'], function (k, j) {

            //labels
            visDir.append('circle')
                .attr('cx', visWidth/3 + j * visWidth/3)
                .attr('cy', i === 0? 12 * dR: visHeight - 12 * dR)
                .attr('r', 6 * dR)
                .attr('fill', colors[k][d]);

            //vals
            visDir.append('text')
                .attr('x', visWidth/4 + (j + 1) * visWidth/6)
                .attr('y', i === 0? 48 * dR: visHeight - 35 * dR)
                .text(0)
                .attr('class', 'vis-text-white js-' + k + '-' + d );
        });
    });

    //histogram
    $('#contacts-vis-time').html('');
    var visTime = d3.select('#contacts-vis-time').append('svg')
        .attr('width', visWidth)
        .attr('height', visHeight + 40 * dR)
        .append('g')
        .attr('transform', 'translate(0, ' + 30 * dR + ')');

    var xVal = d3.scale.ordinal().rangePoints([0, visWidth - 32 * dR]).domain(_.range(9));
    var yVal = d3.scale.linear().range([0, visHeight/2 - 20 * dR]).domain([0, 10]);
    var xAxis = d3.svg.axis().scale(xVal).orient('bottom').tickSize(5 * dR).tickPadding(5 * dR)
                .tickFormat(function(d) { return ['12AM', '3', '6', '9', '12PM', '3', '6', '9', '12AM'][d]; });

    visTime.append('g').attr('transform', 'translate(' + 16 * dR + ', ' + (visHeight/2 - 30 * dR) + ')').attr('class', 'histogram-axis js-hx1');
    d3.select('.js-hx1').call(xAxis);
    visTime.append('g').attr('transform', 'translate(' + 16 * dR + ', ' + (visHeight/2 - 6 * dR) + ')').attr('class', 'histogram-axis js-hx2');
    xAxis.tickFormat('');
    d3.select('.js-hx2').call(xAxis);

    visTime.append('line')
        .attr('x1', 16 * dR)
        .attr('x2', visWidth - 16 * dR)
        .attr('y1', visHeight/2 - 30 * dR)
        .attr('y2', visHeight/2 - 30 * dR)
        .attr('class', 'histogram-axis-y');
    visTime.append('line')
        .attr('x1', 16 * dR)
        .attr('x2', visWidth - 16 * dR)
        .attr('y1', visHeight/2 - 1 * dR)
        .attr('y2', visHeight/2 - 1 * dR)
        .attr('class', 'histogram-axis-y');

    function updateHistogram(id) {
        yVal.domain([0, _.max(_.union(data.topContacts[id].call.outgoing, data.topContacts[id].call.incoming, data.topContacts[id].sms.outgoing, data.topContacts[id].sms.incoming))]);
        $('.js-con-legend-' + selectedKind).css('background-color', '#333333');

        _.each(['outgoing', 'incoming'], function (dir) {
            $('.js-con-histo-' + dir).remove();
            $('.js-con-histo-' + dir + '-text').remove();
            visTime.selectAll('.js-con-histo-' + dir).data(data.topContacts[id][selectedKind][dir])
                .enter()
                .append('rect')
                .attr('x', function(d, i) { return xVal(i) + 16 * dR; })
                .attr('y', function(d) { return dir === 'outgoing'? visHeight/2 - 30 * dR - yVal(d): visHeight/2 - 1 * dR; })
                .attr('width', (visWidth - 32 * dR) / 8)
                .attr('height', function(d) {return yVal(d);})
                .attr('fill', colors[selectedKind][dir])
                .attr('class', 'js-con-histo-outgoing');
            visTime.selectAll('.js-con-histo-' + dir + '-text').data(data.topContacts[id][selectedKind][dir])
                .enter()
                .append('text')
                .attr('x', function(d, i) { return xVal(i) + 16 * dR + (visWidth - 32 * dR) / 16; })
                .attr('y', function(d) { return dir === 'outgoing'? visHeight/2 - 36 * dR - yVal(d): visHeight/2 + yVal(d) + 14 * dR; })
                .text(function(d) {return d; })
                .attr('class', 'histogram-text js-con-histo-outgoing-text');
        });
    }

    function updateContent(id) {

        //highlight selected contact pic
        $('.js-co-pics-list-' + id).find('img').css('border', 'solid 0.2em #36B5E4');

        //title
        if (data.topContacts[id].name === '') {
            $('.js-con-name').html(data.topContacts[id].number);
            $('.js-con-num').css('display', 'none');
        } else {
            $('.js-con-name').html(data.topContacts[id].name);
            $('.js-con-num').css('display', 'block');
            $('.js-con-num').html(data.topContacts[id].number);
        }

        //incoming-outgoing
        var sumDirection = {};
        _.each(['outgoing', 'incoming'], function (d) {
            sumDirection[d] = {};
            _.each(['sms', 'call'], function (k) {
                sumDirection[d][k] = _.reduce(data.topContacts[id][k][d], function (memo, num) { return memo + num; }, 0);
                $('.js-' + k + '-' + d).html(sumDirection[d][k]);
            });
        });
        var maxCount = Math.max(sumDirection.outgoing.call + sumDirection.outgoing.sms, sumDirection.incoming.call + sumDirection.incoming.sms);
        _.each(['outgoing', 'incoming'], function (d, i) {
            var sum = _.reduce(sumDirection[d], function (memo, num) { return memo + num; }, 0);
            var newW = (visWidth/3*2 - 80 * dR - 10 * dR)/maxCount * sum + 10 * dR; // minimum value (0) has 10px
            $('.js-arrow-' + d).attr('width', newW).attr('x', (i === 0? -10: 0) - newW/2);
            var newX = visWidth/2 + 5 * dR + (i === 0? 1: -1) * newW/2 + (i === 0? -12: 2) * dR;
            $('.js-arrow-head-' + d).attr('transform', 'translate(' + newX + ', ' + (i === 0? 50 * dR: visHeight - 70 * dR) + ')');
        });

        //--here comes the picture change
        //$('.js-contact-selected-pic'). //

        //histogram
        updateHistogram(selectedId);
    }

    //default as #1 contact
    updateContent(0);

    //histogram swap
    $('.js-con-legend').click(function() {
        $('.js-con-legend').css('background-color', '');
        $(this).css('background-color', '#333333');
        selectedKind = $(this).data().value;
        updateHistogram(selectedId);
    });
}

//locations
function showLocations() {

    function updateMap(id) {
        $('.js-lo-maps-' + id).find('img').css('border', 'solid 0.2em #36B5E4');
        $('.js-lo-main').find('img').attr('src', 'http://image.maps.cit.api.here.com/mia/1.6/mapview?app_id=FBBffQYZooVO6yztAvLN&app_code=Mj6QTZA1rzKGzjs_KWpmzA&' +
            'c=' + data.topLocations[id].lat + ',' + data.topLocations[id].lon + '&rad=1000&z=13&h=' + $('.js-lo-main').innerWidth() + '&w=' + $('.js-lo-main').innerWidth());
        $('.js-lo-main-title').html(data.topLocations[id].city);
    }

    //put the map list
    var mapWidth = Math.floor((width - 36 * dR)/3 - 12 * dR); //3 maps fit the width
    $('.js-lo-maps').html('');
    _.each(data.topLocations, function (d, i) {
        $('.js-lo-maps').append('<span class="locations-maps-list' + (i === data.topLocations.length-1? '--last': '') + ' js-lo-maps-' + i + '" data-value="' + i + '">' +
            '<img src="http://image.maps.cit.api.here.com/mia/1.6/mapview?app_id=FBBffQYZooVO6yztAvLN&app_code=Mj6QTZA1rzKGzjs_KWpmzA&' +
            'c=' + d.lat + ',' + d.lon + '&z=13&h=' + mapWidth + '&w=' + mapWidth + '" class="locations-maps-list-map"></span>'
            );
        $('.js-lo-maps-' + i).click(function() {
            $('.locations-maps-list-map').css('border', 'solid 0.2em #000000');
            updateMap($(this).data().value);
        });
    });

    //update main map
    updateMap(0);
}

function getQueryURL() {
    // month() is counting from 0
    return server + 'token=' + token + '&year=' + durationStart.year() + '&month=' + (durationStart.month() + 1);
}

function showContent(_data) {
    // show content pane

    // cache the data
    data = replaceUIdsWithContactDetails(_data);

    if (tab === 'actions' && data && data.topActions && data.topActions.length) {
        showActions();
        $('.js-actions').css('display', 'block');
    } else if (tab === 'contacts' && data && data.topContacts && data.topContacts.length) {
        showContacts();
        $('.js-contacts').css('display', 'block');
    } else if (tab === 'locations' && data && data.topLocations && data.topLocations.length) {
        showLocations();
        $('.js-locations').css('display', 'block');
    } else {
        $('.js-nocontent').css('display', 'block');
    }
}

function replaceUIdsWithContactDetails(inData){
    if(DataNegotiatorInterface) {
        return JSON.parse(DataNegotiatorInterface.replaceUidWithNameAndNumber(JSON.stringify(inData)));
    }
    return inData;
}

$(document).ready(function () {
    //put the current month in the preiod navigation;
    $('.js-period').html(moment().format('MMMM YYYY').toUpperCase());

    // go to prev or next period
    $('.js-arrow').click(function() {
        var tmp = durationStart.clone();
        tmp.add('month', $(this).data().value);

        if ($(this).data().value > 0 && tmp.isAfter(moment().startOf('month'))) return;

        durationStart.add('month', $(this).data().value);

        $('.js-period').html(durationStart.format('MMMM YYYY').toUpperCase());

        // hide content during loading
        $('.js-content').css('display', 'none');

        $.get(getQueryURL(), function (result) {
            console.log('Got result:', result);
            showContent(result);
        }).fail(function (response) {
            console.error('Error occured fetching analytics data:', response.responseText);
            showContent(null);
        });
    });

    if (token && server) {
        $('.js-period-header').removeClass('hide');
        $.get(getQueryURL(), function (result) {
            console.log('Got result:', result);
            showContent(result);
        }).fail(function (response) {
            console.error('Error occured fetching analytics data:', response.responseText);
            showContent(null);
        });
    } else {
        console.warn('Server information or authentication token missing. Using local dummy data.');
        $('.js-sample-header').removeClass('hide');
        showContent(new Data());
    }
});

}());
